@@ -3,13 +3,14 @@
 #'@param x data (output of \code{\link{calc_ehhs}}).
 #'@param nehhs logical. If \code{TRUE}, plot normalized EHHS.
 #'@param ylim the y limits of the plot
-#'@param type plot type (see \code{\link[graphics]{matplot}}).
+#'@param type plot type (see code{\link[graphics]{plot.default}}.
+#'Type \code{"s"} or \code{"S"} yield both (the same) piecewise constant curve.
 #'@param main title for the plot (default \code{NA}, i.e. none).
 #'@param xlab title for the x-axis.
 #'@param ylab title for the y-axis.
 #'@param bty box type around plot (see \code{\link[graphics]{par}}).
 #'@param mrk.col color of the vertical line at the focal marker position.
-#'@param ... further arguments to be passed to function \code{\link[graphics]{plot}}.
+#'@param ... further arguments to be passed to function \code{\link[graphics]{plot.default}}.
 #'@seealso \code{\link{data2haplohh}}, \code{\link{plot.ehh}}, \code{\link{calc_ehhs}}, \code{\link{scan_hh}}.
 #'@examples
 #'#example haplohh object (280 haplotypes, 1424 SNPs)
@@ -65,29 +66,57 @@ plot.ehhs <- function(x,
   scale <- 1000 ** max(0, p)
   ## no unit if p < 0
   unit <- c("", "(bp)", "(kb)", "(Mb)", "(Gb)")[max(-1, p)  + 2]
-
+  
   dot_args <- list(...)
   if (!is.null(dot_args$xlim)) {
     dot_args$xlim <- dot_args$xlim / scale
+  } else{
+    dot_args$xlim <- range(x$ehhs$POSITION / scale)
   }
   
   do.call("plot", c(
     list(
-      x = x$ehhs$POSITION / scale,
-      y = ehhs,
+      0,
       ylim = ylim,
-      type = type,
       main = main,
-      xlab = paste(xlab, unit),
+      xlab = ifelse(xlab == "Position", paste(xlab, unit), xlab),
       ylab = ylab,
       bty = "n"
     ),
     dot_args
   ))
   
+  # split data into left and right (necessary for step-wise curve)
+  foc_index <- which(x$ehhs$POSITION == foc_pos)
+  left_x <- x$ehhs$POSITION[1:foc_index]
+  left_y <- ehhs[1:foc_index]
+  right_x <- x$ehhs$POSITION[foc_index:length(x$ehhs$POSITION)]
+  right_y <- ehhs[foc_index:length(x$ehhs$POSITION)]
+  
+  # change all "s" to upper case
+  type <- chartr("s", "S", type)
+  
+  do.call("matlines", c(list(
+    x = left_x / scale,
+    y = left_y,
+    type = type
+  ),
+  dot_args))
+  
+  # change all "S" to lower case
+  type <- chartr("S", "s", type)
+  
+  do.call("matlines", c(
+    list(
+      x = right_x / scale,
+      y = right_y,
+      type = type
+    ),
+    dot_args
+  ))
   
   abline(v = foc_pos / scale,
          lty = 2,
          col = mrk.col)
-
+  
 }
